==> v8.3.zip: ru_twords_ru_tw/bible/other/tongue.md <==
# язык, языки

## Определение:

Слово “язык” является многозначным. В Библии это слово употребляется в ряде прямых и переносных значений.

* Наиболее часто это слово употребляется в значении “речь” или “словесный язык”.
* Иногда “язык” может означать инструмент общения, на котором разговаривает какой-либо народ.
* Иногда он означает сверхъестественный язык, который Святой Дух даёт верующим в Христа как один из Своих даров.
* Выражение “языки пламени” означает “огонь”.
* В выражении “возвеселился мой язык” под словом “язык” подразумевается весь человек. (См.: [synecdoche](rc://*/ta/man/translate/figs-synecdoche))
* Фраза “лживые языки” означает людей, говорящих неправду. (См.: [metonymy](rc://*/ta/man/translate/figs-metonymy))
* Слово “язык” в прямом значении означает физический орган, находящийся во рту человека.

## Варианты перевода:

* В зависимости от контекста слово “язык” может переводиться как “словесная речь” или “духовный язык”. Если не ясно, о чём идёт речь, то лучше всего использовать одно слово — “язык”.
* Словосочетание “языки пламени” можно перевести как “пламя”, “огонь”.
* Выражение “возвеселился мой язык” можно перевести как “я радуюсь”, “мне хорошо”, “я нахожусь в прекрасном расположении духа”.
* Словосочетание “лживый язык” можно перевести как “человек, говорящий ложь”.
* Словосочетание “своим языком” можно перевести как “своими словами”.

(См. также: [дар](../kt/gift.md), [Святой Дух](../kt/holyspirit.md), [радость](../other/joy.md), [хвала](../other/praise.md), [радоваться](../other/joy.md), [дух](../kt/spirit.md))

## Ссылки на библейский текст:

* [1 Кор. 12:9-11](rc://*/tn/help/1co/12/09)
* [1 Ин. 3:16-18](rc://*/tn/help/1jn/03/16)
* [2 Цар. 23:1-2](rc://*/tn/help/2sa/23/01)
* [Деян. 2:25-26](rc://*/tn/help/act/02/25)
* [Иез. 36:1-3](rc://*/tn/help/ezk/36/01)
* [Флп. 2:9-11](rc://*/tn/help/php/02/09)

## Данные о слове:

* Номера Стронга: H762, H2013, H2790, H3956, G1100, G1258, G1447, G2084

==> v9.2.zip: ru_twords_ru_tw/bible/other/tongue.md <==
# язык, языки

## Определение:

Слово “язык” является многозначным. В Библии это слово употребляется в ряде прямых и переносных значений.
* Наиболее часто это слово употребляется в значении “речь” или “словесный язык”.
* Иногда “язык” может означать инструмент общения, на котором разговаривает какой-либо народ.
* Иногда он означает сверхъестественный язык, который Святой Дух даёт верующим в Христа как один из Своих даров.
* Выражение “языки пламени” означает “огонь”.
* В выражении “возвеселился мой язык” под словом “язык” подразумевается весь человек. (См.: [synecdoche](rc://ru/ta/man/translate/figs-synecdoche))
* Фраза “лживые языки” означает людей, говорящих неправду. (См.: [metonymy](rc://ru/ta/man/translate/figs-metonymy))
* Слово “язык” в прямом значении означает физический орган, находящийся во рту человека.

## Варианты перевода:

* В зависимости от контекста слово “язык” может переводиться как “словесная речь” или “духовный язык”. Если не ясно, о чём идёт речь, то лучше всего использовать одно слово — “язык”.
* Словосочетание “языки пламени” можно перевести как “пламя”, “огонь”.
* Выражение “возвеселился мой язык” можно перевести как “я радуюсь”, “мне хорошо”, “я нахожусь в прекрасном расположении духа”.
* Словосочетание “лживый язык” можно перевести как “человек, говорящий ложь”.
* Словосочетание “своим языком” можно перевести как “своими словами”.

(См. также: [дар](../kt/gift.md), [Святой Дух](../kt/holyspirit.md), [радость](../other/joy.md), [хвала](../other/praise.md), [радоваться](../other/joy.md), [дух](../kt/spirit.md))

## Ссылки на библейский текст:

* [1 Кор. 12:9-11](rc://ru/tn/help/1co/12/09)
* [1 Ин. 3:16-18](rc://ru/tn/help/1jn/03/16)
* [2 Цар. 23:1-2](rc://ru/tn/help/2sa/23/01)
* [Деян. 2:25-26](rc://ru/tn/help/act/02/25)
* [Иез. 36:1-3](rc://ru/tn/help/ezk/36/01)
* [Флп. 2:9-11](rc://ru/tn/help/php/02/09)

## Данные о слове:

* Номера Стронга: H762, H2013, H2790, H3956, G1100, G1258, G1447, G2084
